summaryrefslogtreecommitdiffstats
path: root/ksirc/toplevel.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:22:10 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:22:10 -0600
commit3e4d718796cddcc798d9f737037ef4bad540a0af (patch)
tree69d0aaad3f8f46c1dbb4939b7fcda8e7de12c481 /ksirc/toplevel.cpp
parent50d6569cdef5f0aac099f5d01864bd0e14f82ae3 (diff)
downloadtdenetwork-3e4d718796cddcc798d9f737037ef4bad540a0af.tar.gz
tdenetwork-3e4d718796cddcc798d9f737037ef4bad540a0af.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'ksirc/toplevel.cpp')
-rw-r--r--ksirc/toplevel.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/ksirc/toplevel.cpp b/ksirc/toplevel.cpp
index 57f26fb5..34e63182 100644
--- a/ksirc/toplevel.cpp
+++ b/ksirc/toplevel.cpp
@@ -218,7 +218,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
/*
* Ok, let's look at the basic widget "layout"
* Everything belongs to q TQFrame F, this is use so we
* can give the KApplication a single main client widget, which is needs.
*
* A TQVbox and a TQHbox is used to ctronl the 3 sub widget
* The Modified TQListBox is then added side by side with the User list box.
@@ -271,7 +271,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
// f = new kstInside(top, TQString(TQObject::name()) + "_" + "kstIFrame");
top->setStretchFactor(pan, 1);
- setCentralWidget(top); // Tell the KApplication what the main widget is.
+ setCentralWidget(top); // Tell the TDEApplication what the main widget is.
logFile = 0;
if ( ksopts->chan(m_channelInfo).logging && (m_channelInfo.channel() != "!no_channel" ))
@@ -1497,8 +1497,8 @@ void KSircTopLevel::openQueryFromNick(const TQString &nick)
void KSircTopLevel::pasteToWindow()
{
// Ctrl-V
- //kdDebug(5008) << "Going to paste: " << KApplication::clipboard()->text( TQClipboard::Clipboard ) << endl;
- slotTextDropped(KApplication::clipboard()->text( TQClipboard::Clipboard ) );
+ //kdDebug(5008) << "Going to paste: " << TDEApplication::clipboard()->text( TQClipboard::Clipboard ) << endl;
+ slotTextDropped(TDEApplication::clipboard()->text( TQClipboard::Clipboard ) );
}
void KSircTopLevel::pasteToNickList(int button,
@@ -1510,7 +1510,7 @@ void KSircTopLevel::pasteToNickList(int button,
emit open_toplevel(ci);
TQStringList lines = TQStringList::split( '\n',
- KApplication::clipboard()->text( TQClipboard::Selection ),
+ TDEApplication::clipboard()->text( TQClipboard::Selection ),
true );
TQStringList::ConstIterator it = lines.begin();
TQStringList::ConstIterator end = lines.end();
@@ -218,7 +218,7 @@ KSircTopLevel::KSircTopLevel(KSircProcess *_proc, const KSircChannel &channelInf
* Ok, let's look at the basic widget "layout"
* Everything belongs to q TQFrame F, this is use so we
- * can give the KApplication a single main client widget, which is needs.
+ * can give the TDEApplication a single main client widget, which is needs.
*
* A TQVbox and a TQHbox is used to ctronl the 3 sub widget